=======
History
=======

0.1.2 (2016-07-20)
------------------

* (intended difference with : release to PyPI done by Travis.)
* Refactor to use `attrs` classes for clean, fast types.


0.1.1 (2016-07-12)
------------------

* released on pypi (without this note).
* added several tweaks and tuning towards coverage with pytest


0.1.0 (2016-07-12)
------------------

* First release on PyPI.
* Supported Travis-CI, islex.readthedocs.org, and pyup-ci.org
